@@ -4,6 +4,13 @@ from lstchain.io.config import get_cleaning_parameters
 def test_get_standard_config():
     config.get_standard_config()
 
+def test_get_srcdep_config():
+    srcdep_config = config.get_srcdep_config()
+    assert srcdep_config['source_dependent'] == True
+    assert srcdep_config['mc_nominal_source_x_deg'] == 0.4
+    assert srcdep_config['observation_mode'] == 'wobble'
+    assert srcdep_config['n_off_wobble'] == 3
+
 def test_replace_config():
     a = dict(toto=1, tata=2)
     b = dict(tata=3, tutu=4)
