@@ -1,25 +1,25 @@
-import matplotlib.pyplot as plt
-from matplotlib.colors import LogNorm
-from lstchain.spectra.crab import crab_magic, crab_hegra
-from lstchain.visualization.plot_dl2 import plot_pos
-import numpy as np
 import astropy.units as u
+import matplotlib.pyplot as plt
+import numpy as np
 import pandas as pd
 from ctaplot.plots import plot_sensitivity_magic_performance
+from matplotlib.colors import LogNorm
 from pyirf.spectral import CRAB_MAGIC_JHEAP2015
 
+from lstchain.spectra.crab import crab_hegra
+from lstchain.visualization.plot_dl2 import plot_pos
+
 __all__ = [
     'fill_bin_content',
-    'format_axes_ebin',
     'format_axes_array',
+    'format_axes_ebin',
     'format_axes_sensitivity',
     'plot_Crab_SED',
-    'plot_LST_preliminary_sensitivity',
+    'plot_positions_survived_events',
     'plot_sensitivity',
     'sensitivity_minimization_plot',
     'sensitivity_plot_comparison',
-    'plot_positions_survived_events',
-    ]
+]
 
 
 def fill_bin_content(ax, sensitivity, energy_bin, n_bins_gammaness, n_bins_theta2):
@@ -28,7 +28,7 @@ def fill_bin_content(ax, sensitivity, energy_bin, n_bins_gammaness, n_bins_theta
     optimized figure array
 
     Parameters
-    --------
+    ----------
     ax:    `matplotlib.pyplot.axis`
     sensitivity:  `numpy.ndarray`  sensitivity array
     energy_bin:    `int`  energy bin number
@@ -36,7 +36,7 @@ def fill_bin_content(ax, sensitivity, energy_bin, n_bins_gammaness, n_bins_theta
     n_bins_theta2:    `int`  number of bins in theta2
 
     Returns
-    --------
+    -------
     ax:    `matplotlib.pyplot.axis`
 
     """
@@ -49,8 +49,8 @@ def fill_bin_content(ax, sensitivity, energy_bin, n_bins_gammaness, n_bins_theta
             # With gammaness, we start with 0.05 and increase up to n_bins_gammaness steps
             # up to reaching 1
             gammaness = 0.1 / 2 + (1 / n_bins_gammaness) * i
-            text = ax.text(theta2, gammaness, "%.2f %%" % sensitivity[energy_bin][i][j],
-                           ha = "center", va = "center", color = "w", size = 8)
+            ax.text(theta2, gammaness, "%.2f %%" % sensitivity[energy_bin][i][j],
+                    ha="center", va="center", color="w", size=8)
     return ax
 
 
@@ -59,20 +59,20 @@ def format_axes_ebin(ax, img):
     Format axes for the theta2 and gammaness optimization per energy bin
 
     Parameters
-    --------
+    ----------
     ax:    `matplotlib.pyplot.axis`
     img:    `matplotlib.image.AxesImage`
 
     Returns
-    --------
+    -------
     ax:    `matplotlib.pyplot.axis`
 
     """
 
     ax.set_aspect('auto')
 
-    ax.set_ylabel(r'Gammaness', fontsize = 15)
-    ax.set_xlabel(r'$\theta^2$ (deg$^2$)', fontsize = 15)
+    ax.set_ylabel(r'Gammaness', fontsize=15)
+    ax.set_xlabel(r'$\theta^2$ (deg$^2$)', fontsize=15)
 
     starty, endy = ax.get_ylim()
     ax.yaxis.set_ticks(np.arange(endy, starty, 0.1)[::-1])
@@ -80,9 +80,9 @@ def format_axes_ebin(ax, img):
     ax.xaxis.set_ticks(np.arange(startx, endx, 0.01))
 
     fig = ax.get_figure()
-    #cbaxes = fig.add_axes([0.9, 0.125, 0.03, 0.755])
-    cbar = fig.colorbar(img)#, cax=cbaxes)
-    cbar.set_label('Sensitivity (% Crab)', fontsize = 15)
+    # cbaxes = fig.add_axes([0.9, 0.125, 0.03, 0.755])
+    cbar = fig.colorbar(img)  # , cax=cbaxes)
+    cbar.set_label('Sensitivity (% Crab)', fontsize=15)
 
 
 def format_axes_array(ax, arr_i, arr_j, plot):
@@ -91,14 +91,14 @@ def format_axes_array(ax, arr_i, arr_j, plot):
     figure array with all energy bins together
 
     Parameters
-    --------
+    ----------
     ax:    `matplotlib.pyplot.axis`
     arr_i: `int` i index for the square plot
     arr_j: `int` j index for the square plot
     plot:  `matplotlib.pyplot.figure`
 
     Returns
-    --------
+    -------
     ax:    `matplotlib.pyplot.axis`
     """
     ax.set_aspect(0.5)
@@ -131,8 +131,8 @@ def format_axes_sensitivity(ax):
     `matplotlib.pyplot.axis`
     """
 
-    ax.set_xscale("log", nonposx='clip')
-    ax.set_yscale("log", nonposy='clip')
+    ax.set_xscale("log", nonpositive='clip')
+    ax.set_yscale("log", nonpositive='clip')
     # ax.set_xlim(5e-2, 9.e1)
     # ax.set_ylim(1.e-14, 5.e-10)
     ax.set_xlabel("Energy [TeV]")
@@ -145,7 +145,7 @@ def plot_Crab_SED(emin, emax, percentage=100, ax=None, **kwargs):
     Plot a percentage of the Crab SED
 
     Parameters
-    --------
+    ----------
     emin: `astropy.units.quantity.Quantity` compatible with energies
     emax:  astropy.units.quantity.Quantity compatible with energies
     percentage:  `float`  percentage of the Crab Nebula to be plotted
@@ -153,21 +153,21 @@ def plot_Crab_SED(emin, emax, percentage=100, ax=None, **kwargs):
     kwargs: kwargs for `matplotlib.pyplot.plot`
 
     Returns
-    --------
+    -------
     ax:    `matplotlib.pyplot.axis`
     """
     ax = plt.gca() if ax is None else ax
 
     energy = np.geomspace(emin.to_value(u.TeV), emax.to_value(u.TeV), 40) * u.TeV
 
-    if percentage==100:
-        kwargs.setdefault('label', f'Crab (MAGIC JHEAP 2015)')
+    if percentage == 100:
+        kwargs.setdefault('label', 'Crab (MAGIC JHEAP 2015)')
     else:
         kwargs.setdefault('label', f'{percentage}% Crab (MAGIC JHEAP 2015)')
 
     kwargs.setdefault('color', 'gray')
     ax.plot(energy.to_value(u.TeV),
-            percentage/100. * (energy**2 * CRAB_MAGIC_JHEAP2015(energy)).to_value(u.TeV / (u.cm * u.cm * u.s)),
+            percentage / 100. * (energy ** 2 * CRAB_MAGIC_JHEAP2015(energy)).to_value(u.TeV / (u.cm * u.cm * u.s)),
             **kwargs
             )
     ax.set_xscale('log')
@@ -183,13 +183,13 @@ def plot_sensitivity(energy, sensitivity, ax=None, **kwargs):
     Plot the achieved sensitivity
 
     Parameters
-    --------
+    ----------
     ax:          `matplotlib.pyplot.axis`
     energy:      `astropy.units.quantity.Quantity`  energy array
     sensitivity: `numpy.ndarray`  sensitivity array (bins of energy)
 
     Returns
-    --------
+    -------
     ax:    `matplotlib.pyplot.axis`
 
     """
@@ -219,8 +219,9 @@ def sensitivity_minimization_plot(n_bins_energy, n_bins_gammaness, n_bins_theta2
     cuts were properly applied
 
     TODO: Save plots!
+
     Parameters
-    --------
+    ----------
     n_bins_energy:    `int`  number of bins in energy
     n_bins_gammaness:    `int`  number of bins in gammaness
     n_bins_theta2:    `int`  number of bins in theta2
@@ -228,12 +229,11 @@ def sensitivity_minimization_plot(n_bins_energy, n_bins_gammaness, n_bins_theta2
     sensitivity_3Darray: `numpy.ndarray`  sensitivity array (bins of energy, gammaness and theta2)
 
     Returns
-    --------
+    -------
     figarr: `matplotlib.pyplot.figure`
-
     """
 
-    #TODO : To be changed!!!
+    # TODO: To be changed!!!
     # if (n_bins_energy == 12):
     #     figarr, axarr = plt.subplots(4,3, sharex=True, sharey=True, figsize=(13.2,18))
 
@@ -279,15 +279,14 @@ def sensitivity_plot_comparison(energy, sensitivity, ax=None):
     We plot the sensitivity achieved, MAGIC sensitivity and Crab SEDs
 
     Parameters
-    --------
+    ----------
     n_bins_energy:   `int`  number of bins in energy
     energy:    `numpy.ndarray`  sensitivity array
     sens: `numpy.ndarray`  sensitivity array (bins of energy, gammaness and theta2)
 
     Returns
-    --------
+    -------
     fig_sens: `matplotlib.pyplot.figure` Figure containing sensitivity plot
-
     """
 
     # Final sensitivity plot
@@ -319,7 +318,7 @@ def plot_positions_survived_events(df_gammas,
     Plot positions of surviving events after cuts
 
     Parameters
-    --------
+    ----------
     df_gammas: `pandas.DataFrame` gammas dl2 parameters
     df_protons: `pandas.DataFrame` protons dl2 parameters
     gammaness_g: `numpy.ndarray`  gammaness array of gamma events
@@ -332,10 +331,6 @@ def plot_positions_survived_events(df_gammas,
     n_bins_energy: `int`  number of bins in energy
     gammaness_bins: `numpy.ndarray`  gammaness bins
     theta2_bins: `numpy.ndarray`  theta2 bins
-
-    Returns
-    --------
-
     """
 
     e_reco_g = df_gammas.reco_energy
