@@ -15,6 +15,8 @@ import pandas as pd
 import tables
 from scipy.interpolate import interp1d
 from astropy.table import Table
+from ctapipe.calib.camera import CameraCalibrator
+from ctapipe.containers import EventType
 from ctapipe.image import (
     HillasParameterizationError,
     hillas_parameters,
@@ -24,18 +26,17 @@ from ctapipe.image import number_of_islands, apply_time_delta_cleaning
 from ctapipe.io import EventSource, HDF5TableWriter
 from ctapipe.utils import get_dataset_path
 from traitlets.config import Config
-from ctapipe.calib.camera import CameraCalibrator
-from ctapipe.containers import EventType
+
 from . import disp
 from .utils import sky_to_camera
 from .volume_reducer import apply_volume_reduction
-from ..analysis import NormalizedPulseTemplate
+from ..data import NormalizedPulseTemplate
 from ..calib.camera import load_calibrator_from_config
 from ..calib.camera.calibration_calculator import CalibrationCalculator
-from ..image.muon import analyze_muon_event, tag_pix_thr
-from ..image.muon import create_muon_table, fill_muon_event
 from ..image.cleaning import apply_dynamic_cleaning
 from ..image.modifier import tune_nsb_on_waveform, calculate_required_additional_nsb
+from ..image.muon import analyze_muon_event, tag_pix_thr
+from ..image.muon import create_muon_table, fill_muon_event
 from ..io import (
     DL1ParametersContainer,
     replace_config,
@@ -52,10 +53,10 @@ from ..io import (
     write_simtel_energy_histogram,
     write_subarray_tables,
 )
-from ..io.io import add_column_table, extract_simulation_nsb
+
+from ..io.io import add_column_table, extract_simulation_nsb, dl1_params_lstcam_key
 from ..io.lstcontainers import ExtraImageInfo, DL1MonitoringEventIndexContainer
 from ..paths import parse_r0_filename, run_to_dl1_filename, r0_to_dl1_filename
-from ..io.io import dl1_params_lstcam_key
 
 logger = logging.getLogger(__name__)
 
@@ -80,8 +81,8 @@ def setup_writer(writer, subarray, is_simulation):
     writer.exclude('subarray/trigger', 'tel')
 
     # Forcing filters for the dl1 dataset that are currently read from the pre-existing files
-    writer._h5file.filters = HDF5_ZSTD_FILTERS
-    logger.info(f"USING FILTERS: {writer._h5file.filters}")
+    writer.h5file.filters = HDF5_ZSTD_FILTERS
+    logger.info(f"USING FILTERS: {writer.h5file.filters}")
 
 
     tel_names = {str(tel)[4:] for tel in subarray.telescope_types}
@@ -120,12 +121,52 @@ def setup_writer(writer, subarray, is_simulation):
             writer.exclude(f'telescope/parameters/{tel_name}', 'mc_core_distance')
 
 
+def _camera_distance_to_angle(distance, focal_length):
+    '''Convert a distance in the camera plane into an angle
+
+    This should be replaced by calculating image parameters in
+    telescope frame.
+    '''
+    return np.rad2deg(np.arctan(distance / focal_length))
+
+
+def parametrize_image(image, peak_time, signal_pixels, camera_geometry, focal_length, dl1_container):
+    '''
+    Calculate image parameters and fill them into ``dl1_container``
+    '''
+
+    geom_selected = camera_geometry[signal_pixels]
+    image_selectecd = image[signal_pixels]
+    hillas = hillas_parameters(geom_selected, image_selectecd)
+
+    # Fill container
+    dl1_container.fill_hillas(hillas)
+
+    # convert ctapipe's width and length (in m) to deg:
+
+    for key  in ['width', 'width_uncertainty', 'length', 'length_uncertainty']:
+        value = getattr(dl1_container, key)
+        setattr(dl1_container, key, _camera_distance_to_angle(value, focal_length))
+
+    dl1_container.wl = dl1_container.width / dl1_container.length
+
+    dl1_container.set_timing_features(
+        geom_selected,
+        image_selectecd,
+        peak_time[signal_pixels],
+        hillas,
+    )
+    dl1_container.set_leakage(camera_geometry, image, signal_pixels)
+    dl1_container.set_concentration(geom_selected, image_selectecd, hillas)
+    dl1_container.log_intensity = np.log10(dl1_container.intensity)
+
+
 def get_dl1(
-        calibrated_event,
-        subarray,
-        telescope_id,
-        dl1_container=None,
-        custom_config={},
+    calibrated_event,
+    subarray,
+    telescope_id,
+    dl1_container=None,
+    custom_config={},
 ):
     """
     Return a DL1ParametersContainer of extracted features from a calibrated event.
@@ -164,6 +205,7 @@ def get_dl1(
     dl1 = calibrated_event.dl1.tel[telescope_id]
     telescope = subarray.tel[telescope_id]
     camera_geometry = telescope.camera.geometry
+    optics = telescope.optics
 
     image = dl1.image
     peak_time = dl1.peak_time
@@ -192,6 +234,7 @@ def get_dl1(
 
         # check the number of islands
         num_islands, island_labels = number_of_islands(camera_geometry, signal_pixels)
+        dl1_container.n_islands = num_islands
 
         if use_main_island:
             n_pixels_on_island = np.bincount(island_labels)
@@ -199,36 +242,20 @@ def get_dl1(
             max_island_label = np.argmax(n_pixels_on_island)
             signal_pixels[island_labels != max_island_label] = False
 
+
         # count surviving pixels
         n_pixels = np.count_nonzero(signal_pixels)
+        dl1_container.n_pixels = n_pixels
 
         if n_pixels > 0:
-            hillas = hillas_parameters(camera_geometry[signal_pixels], image[signal_pixels])
-
-            # Fill container
-            dl1_container.fill_hillas(hillas)
-
-            # convert ctapipe's width and length (in m) to deg:
-            foclen = subarray.tel[telescope_id].optics.equivalent_focal_length
-            width = np.rad2deg(np.arctan2(dl1_container.width, foclen))
-            width_uncertainty = np.rad2deg(np.arctan2(dl1_container.width_uncertainty, foclen))
-            length = np.rad2deg(np.arctan2(dl1_container.length, foclen))
-            length_uncertainty = np.rad2deg(np.arctan2(dl1_container.length_uncertainty, foclen))
-            dl1_container.width = width
-            dl1_container.width_uncertainty = width_uncertainty
-            dl1_container.length = length
-            dl1_container.length_uncertainty = length_uncertainty
-            dl1_container.wl = dl1_container.width / dl1_container.length
-
-            dl1_container.set_timing_features(camera_geometry[signal_pixels],
-                                              image[signal_pixels],
-                                              peak_time[signal_pixels],
-                                              hillas)
-            dl1_container.set_leakage(camera_geometry, image, signal_pixels)
-            dl1_container.set_concentration(camera_geometry, image, hillas)
-            dl1_container.n_pixels = n_pixels
-            dl1_container.n_islands = num_islands
-            dl1_container.log_intensity = np.log10(dl1_container.intensity)
+            parametrize_image(
+                image=image,
+                peak_time=peak_time,
+                signal_pixels=signal_pixels,
+                camera_geometry=camera_geometry,
+                focal_length=optics.equivalent_focal_length,
+                dl1_container=dl1_container,
+            )
 
     # We set other fields which still make sense for a non-parametrized
     # image:
@@ -241,7 +268,7 @@ def get_dl1(
 
 
 def r0_to_dl1(
-    input_filename=get_dataset_path('gamma_test_large.simtel.gz'),
+    input_filename=None,
     output_filename=None,
     custom_config={},
 ):
@@ -262,6 +289,11 @@ def r0_to_dl1(
 
     """
 
+    # using None as default and using `get_dataset_path` only inside the function
+    # prevents downloading at import time.
+    if input_filename is None:
+        get_dataset_path('gamma_test_large.simtel.gz')
+
     if output_filename is None:
         try:
             run = parse_r0_filename(input_filename)
@@ -306,8 +338,7 @@ def r0_to_dl1(
                                                             config=Config(config),subarray = subarray)
 
         # Component to process interleaved pedestal and flat-fields
-        calib_config = Config(config[config['calibration_product']])
-
+        calib_config = Config({config['calibration_product']: config[config['calibration_product']]})
         calibration_calculator = CalibrationCalculator.from_name(
             config['calibration_product'],
             config=calib_config,
